@@ -24,12 +24,39 @@ pub fn log_styled_message_to_console(message: &str, color: ConsoleColors) {
     }
 }
 
-/// Logs the version of the program.
+/// Logs the version of the cli.
 pub fn log_version() {
     let version_notice = format!(
         "{}{}",
         "godot-rust-cli".white().underline(),
         env!("CARGO_PKG_VERSION").white().underline()
     );
-    log_styled_message_to_console(&version_notice, ConsoleColors::WHITE);
+    log_info_to_console(&version_notice);
+}
+
+/// Logs an error message to the console.
+///
+/// # Arguments
+///
+/// `message` - The message to log to the console.
+pub fn log_error_to_console(message: &str) {
+    println!("Error: {}", message.red());
+}
+
+/// Logs an info message to the console.
+///
+/// # Arguments
+///
+/// `message` - The message to log to the console.
+pub fn log_info_to_console(message: &str) {
+    println!("Info: {}", message.cyan());
+}
+
+/// Logs a success message to the console.
+///
+/// # Arguments
+///
+/// `message` - The message to log to the console.
+pub fn log_success_to_console(message: &str) {
+    println!("Success: {}", message.green());
 }
